@@ -66,7 +66,7 @@ class BibTeX(DueCreditEntry):
             self._key = key
 
     def _process_rawentry(self):
-        reg = re.match("\s*@(?P<type>\S*)\s*\{\s*(?P<key>\S*)\s*,.*",
+        reg = re.match(r"\s*@(?P<type>\S*)\s*\{\s*(?P<key>\S*)\s*,.*",
                        self._rawentry, flags=re.MULTILINE)
         assert(reg)
         matches = reg.groupdict()
